\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{MoDeMa}[2017/11/29 Modèle De Manuscrit de thèse after Alain Olivetti]
\LoadClass[a4paper, 12pt, twoside, final]{book}

\RequirePackage[T1]{fontenc}
\RequirePackage[utf8]{inputenc}
\RequirePackage[english,francais]{babel} %add the language you like 

\newcommand*{\myUniversite}    [1][]{University}
\newcommand*{\myUFR}           [1][]{UFR Sciences}
\newcommand*{\myEcoleDoctorale}[1][]{Doctoral School name}
\newcommand*{\myLaboratoire}   [1][Short Laboratory Name]{Laboratory name}
\newcommand*{\myDoctorat}      [1][]{Sciences}
\newcommand*{\mySpecialite}    [1][]{Physique}

\newcommand*{\myAuteur}   [1][Name]{Name}
\newcommand*{\myDate}     [1][]{PhDefense date}
\newcommand*{\myTitre}    [1][]{Title}
\newcommand*{\mySousTitre}[1][]{Subtitle}


\newcommand*{\myDirecteur}       [1][]{Director}
\newcommand*{\myRapporteurUn}    [1][]{Examinator 1}
\newcommand*{\myRapporteurDeux}  [1][]{Examinator 2}
\newcommand*{\myExaminateurUn} [1][]{Jury 1}
\newcommand*{\myExaminateurDeux}   [1][]{Jury 2}
\newcommand*{\myExaminateurTrois}[1][]{Jury 3}
\newcommand*{\myExaminateurQuatre}[1][]{Jury 4}

\newcommand*{\positionDirecteur}       [1][]{Maitre de Conférence HDR, Université d'Orléans}
\newcommand*{\positionRapporteurUn}    [1][]{DR CNRS, Laboratoire de
Probabilités et Modèles}
\newcommand*{\positionRapporteurDeux}  [1][]{Professeur, The University of Texas at Austin}
\newcommand*{\positionExaminateurUn} [1][]{Professeur, Université Côte d'Azur}
\newcommand*{\positionExaminateurDeux}   [1][]{CR CNRS, Laboratoire PIIM}
\newcommand*{\positionExaminateurTrois}[1][]{Professeur, Université de Cergy-Pontoise}
\newcommand*{\positionExaminateurQuatre}[1][]{Professeur, Université Pierre et Marie Curie}



\RequirePackage{fancyhdr}			% gestion de l'en-tête et du pied de page
\RequirePackage{geometry}			% gestion des marges et autres (permet de définir le format du document)
\RequirePackage{chapterbib}			% pour mettre une bibliographie par chapitre (NB : doit être chargé avant ``hyperref'')
\RequirePackage{backref}			% pour les références croisées dans la/les bibliographie(s)
\RequirePackage{engrec}				% pour utiliser des compteurs avec des lettres grecques
\RequirePackage{fmtcount}		    % pour utiliser des compteurs en toute lettre (Un,Deux,...)

\RequirePackage[newparttoc,nobottomtitles]{titlesec}			% pour modifier le format des titres des sections
\RequirePackage[]{titletoc}			% pour modifier le format des titres dans la table des matières
\RequirePackage[backref]{hyperref}


\RequirePackage{apptools}	% To use the command AtAppendix 	


%% Gestion des marges selon la partie du manuscrit concernée
%% Set the various geometry parameter of the different sections (the title page will have a different marging from the body). You can change it.
\geometry{
paperheight=29.7cm,
paperwidth=21cm,
height=25.5cm,
headheight=15.0pt,
headsep=0.5cm,
top=2.0cm,
footskip=1cm,
left=1.75cm,
right=1.75cm
}\savegeometry{PDG_geometry} % Format de la Page de Garde
\newcommand{\myPageDeGarde}{\pagenumbering{roman}\loadgeometry{PDG_geometry}}


\geometry{
paperheight=29.7cm,
paperwidth=21cm,
height=24.5cm,
headheight=15.0pt,
headsep=0.5cm,
top=2.5cm,
footskip=1cm,
left=3cm,
right=2cm
}\savegeometry{TDM_geometry} % Format de la majeur partie de la thèse
\newcommand{\myTableDesMatieres}{\renewcommand{\thepage}{\roman{page}}\loadgeometry{TDM_geometry}}

\geometry{
paperheight=29.7cm,
paperwidth=21cm,
height=25.5cm,
headheight=15.0pt,
headsep=0.5cm,
top=1.5cm,
footskip=1cm,
left=1.5cm,
right=1.5cm
}\savegeometry{DDC_geometry}
\newcommand{\myDosDeCouverture}{\cleardoublepage\thispagestyle{empty}\loadgeometry{DDC_geometry}}

\geometry{
paperheight=29.7cm,
paperwidth=21cm,
height=24.5cm,
headheight=15.0pt,
headsep=0.5cm,
top=2.5cm,
footskip=1cm,
left=3cm,
right=2cm
}\savegeometry{CDM_geometry} % Format de la majeur partie de la thèse
\newcommand{\myCorpsDuManuscrit}{\newpage\thispagestyle{empty}\renewcommand{\thepage}{\arabic{page}}\loadgeometry{CDM_geometry}}




%% Divers
\parindent=0.5cm			% indentation par défaut
\hfuzz=3.2pt				% débordement autorisé dans la marge de droite (par défaut 0.5 pt)
\everymath{\displaystyle}	% mode mathématique appliqué partout (dans $ $ ou $$ $$)

%% Gestion de l'en-tête et du pied de page
%\lhead[\begin{small}\leftmark\end{small}]{\begin{small}\rightmark\end{small}} % Rq : ``\leftmark'' affiche le dernier chapitre vu, ``\rightmark'' affiche la dernière section vue
\lhead[\begin{small}\leftmark\end{small}]{} % Rq : ``\leftmark'' affiche le dernier chapitre vu, ``\rightmark'' affiche la dernière section vue
\rhead[]{\begin{small}\rightmark\end{small}}
\chead[]{}
\lfoot[\footnotesize \myUniversite]{}
\cfoot{\thepage}
\rfoot[]{\footnotesize \myLaboratoire}
\renewcommand{\footrulewidth}{.4pt}
\pagestyle{fancy}  % déclarer que l'on va utiliser cette entête et ce pied de page

%% Gestion de la numérotation des titres
\renewcommand\thepart{\Numberstring{part}}   %Personal choice to put the names of Parts in letters e.g. Part One, Part Two (choice motivated by the fact that other letters/numbers were already taken).
\setcounter{secnumdepth}{5}  % 1:section - 2:subsection - 3:subsubsection
\renewcommand\thechapter{\Roman{chapter}}
\renewcommand\thesection{\arabic{section}}
\renewcommand\thesubsection{\thesection.\arabic{subsection}} 
\renewcommand\thesubsubsection{\thesubsection.\alph{subsubsection}} 
\renewcommand\theparagraph{\roman{paragraph}} 
\renewcommand\thesubparagraph{\engrec{subparagraph}}

%%Cite sections/subsection/subsubsection/paragraph with their Chapter number ( e.g. X.2.1.a instead of 2.1.a which is useful to cite sections of different Chapters
\makeatletter
\renewcommand*{\p@section}{\thechapter.}
\makeatother
\makeatletter
\renewcommand*{\p@subsection}{\thechapter.}
\makeatother
\makeatletter
\renewcommand*{\p@subsubsection}{\thechapter.}
\makeatother
\makeatletter
\renewcommand*{\p@paragraph}{\thechapter.}
\makeatother

%%Display of the Part/Chapter/Section/etc, you can change it if you don't like it
%% Gestion des titres des sections, sous-sections
%% Usage ``\titleformat{ command }[ shape ]{ format }{ label }{ sep }{ before }[ after ]''
\titleformat{\part}[display]{\centering\Huge\scshape\bfseries}{\rule[3pt]{0.25\linewidth}{4.5pt}\quad Part\ \thepart\quad \rule[4pt]{0.25\linewidth}{4.5pt}}{2\baselineskip}{\vspace*{\stretch{5}}}[\vspace*{\stretch{6}}]

\titleformat{\chapter}[display]{\centering\normalfont\large\scshape\bfseries}{\rule[3pt]{0.15\linewidth}{3pt}\quad\chaptertitlename\ \thechapter\quad \rule[3pt]{0.15\linewidth}{3pt}}{2\baselineskip}{\rule{\linewidth}{0.5pt}\break\Huge}[\vspace{-0.5\baselineskip}\rule{\linewidth}{0.5pt}\vspace{2\baselineskip}]

\titleformat{\section}[block]{\Large\scshape\bfseries}{\thesection}{\baselineskip}{}[\hrule\vspace{2pt}\hrule\vspace{1\baselineskip}]
\titleformat{\subsection}[block]{\normalfont\large\bfseries}{\thesubsection}{\baselineskip}{}[\hrule\vspace{0.75\baselineskip}]

\titleformat{\subsubsection}[block]{\itshape\normalsize\bfseries}{\normalfont\bfseries \thesubsubsection}{\baselineskip}{}[\vspace{0.5\baselineskip}]
\titleformat{\paragraph}[block]{\itshape}{\theparagraph )}{\baselineskip}{}[]
\titleformat{\subparagraph}[block]{}{\thesubparagraph~:}{\baselineskip}{}[]



\setcounter{tocdepth}{5} 

%%%%%%%Part in ToC
\AtAppendix{
\titlecontents{part}[0pt]{\addvspace{2pc}\scshape\bfseries\Large \protect\centering}{}{}{\hrule height 2pt}[]
}

\titlecontents{part}[0pt]{\addvspace{2pc}\scshape\bfseries\Large \protect\centering Part\ \thecontentslabel\\}{}{}{\hrule height 2pt}[]

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%Chapter in ToC%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%If you feel like you want you can make changes on the display of the Parts/Chapter/Subsections/ect in the Table of Content.

%Display of the Appendix
\AtAppendix{
\titlecontents{chapter}[100pt]{\addvspace{2pc}\scshape\bfseries\large}{\contentslabel[Appendix\ \thecontentslabel]{100pt}}{}{\hrule\vspace{2pt}\hrule}[]
}
%Display of the Chapter
\titlecontents{chapter}[100pt]{\addvspace{2pc}\scshape\bfseries\large}{\contentslabel[Chapter\ \thecontentslabel]{100pt}}{}{\hrule\vspace{2pt}\hrule}[] 
%Display of the Section
\titlecontents{section}[25pt]{\addvspace{1pc}\scshape\normalsize}{\contentslabel[\thecontentslabel]{20pt}}{}{{\normalsize\dotfill}\bfseries\thecontentspage}[]
%Display of the Subsection
\titlecontents{subsection}[75pt]{\addvspace{0.5pc}\normalfont\small}{\contentslabel[\thecontentslabel]{30pt}}{}{{\normalsize\dotfill}\thecontentspage}[]
%Display of the Subsubsection
\titlecontents{subsubsection}[125pt]{\addvspace{0.pc}\normalfont\footnotesize}{\contentslabel[\thecontentslabel]{30pt}\itshape}{}{{\normalsize\dotfill}\itshape\thecontentspage}[]
%Display of the Paragraph
\titlecontents{paragraph}[175pt]{\addvspace{0.pc}\normalfont\scriptsize}{\contentslabel[\thecontentslabel )]{15pt}\itshape}{}{{\normalsize\dotfill}\itshape\thecontentspage}[]
\contentsfinish

\makeatletter
\renewcommand\@pnumwidth{5pt}
\makeatother


%%This is useful in order to write the number of time a reference is used.
%% Références croisées dans les bibliographies 
\newcommand{\mapolicebackref}[1]{\hspace*{\fill} \mbox{\textit {\scriptsize #1}}\medskip}
\renewcommand*{\backref}[1]{}	%	enlève le rappel de la page standard du package
\renewcommand*{\backrefalt}[4]{	%	création de son propre rappel de la page ou la citation est faite
	\ifcase #1 
				\mapolicebackref{- No citations -} 
		\or 	\mapolicebackref{- Cited 1 time: page #2 -} 
		\else 	\mapolicebackref{- Cited #1 times: pages #2 -} 
	\fi }
\renewcommand*{\backreftwosep}{~and~}
\renewcommand*{\backreflastsep}{~and~}





%% Paramétrage du pdf et liens



%Unfortunatly I did not understand why commands like
%	pdfauthor={\myAuteur}
% foes not work so you have to re-enter manually these informations
%%These commands are used to defined the ouput pdf file propreties 
%\newcommand*{\mySujet}    [1][]{mySubject}
%\newcommand*{\myMotsCles} [1][]{mykeywords} %This one is useless in this setting because linked with nothing (after several tentative it did not worked)

\hypersetup%
{
	bookmarksopen=false,
	bookmarksnumbered=true,
	pdfpagelayout=SinglePage,
	pdfpagemode=UseOutlines,
	pdfstartview=FitH,
	colorlinks = true,
	urlcolor = blue,
	linkcolor=blue, 
	linktoc=all,
	urlcolor=blue,
	anchorcolor=black,
	citecolor=red,
	frenchlinks=true,
	pdffitwindow=true,
	pdftoolbar=true,
	pdfmenubar=true, 
	pdfauthor={Name}
	pdfsubject={Subjects},
	pdftitle = {Title},
	pdfkeywords = {Keyword},
	pdfcreator=PDFLaTeX,
	pdfproducer=PDFLaTeX,
	plainpages = false
}

